/**
 * apeman react package for card components
 * @class ApCard
 */

'use strict'

import React, {PropTypes as types} from 'react'
import classnames from 'classnames'
import {ApImage} from 'apeman-react-image'
import {ApTouchable} from 'apeman-react-touchable'

/** @lends ApCard */
const ApCard = React.createClass({

  // --------------------
  // Specs
  // --------------------

  propTypes: {
    /** Source of image */
    imgSrc: types.string,
    /** Alt text of image */
    imgAlt: types.string,
    /** Scale policy of image */
    imgScale: types.string,
    /** Width of image */
    imgWidth: types.oneOfType([ types.number, types.string ]),
    /** Height of image */
    imgHeight: types.oneOfType([ types.number, types.string ]),

    /** Title text */
    title: types.string,
    /** Content text */
    text: types.string
  },

  mixins: [],

  statics: {},

  getInitialState () {
    return {}
  },

  getDefaultProps () {
    return {
      imgScale: 'fit',
      imgWidth: 128,
      imgHeight: 'auto'
    }
  },

  render () {
    const s = this
    let { state, props } = s

    return (
      <ApTouchable { ...props }
        className={ classnames('ap-card', {
          'ap-card-tappable': !!props.onTap
        },props.className) }
        style={ Object.assign({}, props.style) }>
        <div className="ap-card-column ap-card-column-0">
          { s._renderImage(props.imgSrc, props.imgAlt, props.imgScale, props.imgWidth, props.imgHeight) }
        </div>
        <div className="ap-card-column">
          { s._renderTitle(props.title) }
          { s._renderText(props.text) }
          { props.children }
        </div>
      </ApTouchable>
    )
  },

  // --------------------
  // Lifecycle
  // --------------------

  // ------------------
  // Custom
  // ------------------

  // ------------------
  // Private
  // ------------------

  _renderImage (src, alt, scale, width, height) {
    if (!src) {
      return null
    }
    let props = { src, alt, scale, width, height }
    return (
      <ApImage { ...props }
        className="ap-card-image"
      />
    )
  },

  _renderTitle (title) {
    if (!title) {
      return null
    }
    return (
      <h3 className="ap-card-title">{ title }</h3>
    )
  },

  _renderText (text) {
    if (!text) {
      return null
    }
    return (
      <p className="ap-card-text">{ text }</p>
    )
  }
})

export default ApCard
