/**
 * Style for ApCard.
 * @class ApCardStyle
 */

'use strict'

import React, {PropTypes as types} from 'react'
import {ApStyle} from 'apeman-react-style'

/** @lends ApCardStyle */
const ApCardStyle = React.createClass({
  propTypes: {
    style: types.object,
    highlightColor: types.string
  },
  getDefaultProps () {
    return {
      style: {},
      highlightColor: ApStyle.DEFAULT_HIGHLIGHT_COLOR,
      backgroundColor: ApStyle.DEFAULT_BACKGROUND_COLOR
    }
  },
  statics: {
    styleData (config) {
      let { highlightColor, backgroundColor } = config
      return {
        all: {
          '.ap-card': {
            display: 'flex',
            borderRadius: '2px',
            boxSizing: 'border-box',
            padding: '4px',
            boxShadow: '2px 2px 4px rgba(0,0,0,0.33)',
            backgroundColor: backgroundColor,
            maxWidth: `${ApStyle.CONTENT_WIDTH}px`,
            border: '1px solid #D4D4D4',
            margin: '16px 8px',
            flexWrap: 'wrap'
          },
          '.ap-card-tappable:hover': {
            cursor: 'pointer'
          },
          '.ap-card-tappable:active': {
            boxShadow: 'none'
          },
          '.ap-card-image': {
            margin: '4px auto',
            maxWidth: '100%',
            overflow: 'hidden',
            boxSizing: 'border-box',
            padding: '0 4px'
          },
          '.ap-card-column': {
            display: 'block',
            width: '100%'
          },
          '.ap-card-column-0': {
            flexBasis: 0
          },
          '.ap-card-title': {
            padding: '4px',
            margin: 0
          },
          '.ap-card-text': {
            padding: '4px',
            margin: 0
          },
          '.ap-card-group': {
            display: 'flex',
            flexWrap: 'wrap',
            justifyContent: 'space-around'
          }
        }
      }
    }
  },
  render () {
    const s = this
    let { props } = s

    let { all, small, medium, large } = ApCardStyle.styleData(props)

    return (
      <ApStyle data={ Object.assign(all, props.style) }
               smallMediaData={ small }
               mediumMediaData={ medium }
               largeMediaData={ large }
      >{ props.children }</ApStyle>
    )
  }
})

export default ApCardStyle
